struct EntryWriter<'a, T: Write> {
entry: &'a mut QlieEntry,
inner: T,
hasher: Encryption31Hasher,
}Available on crate features
qlie and qlie-arc only.Fields
entry: &'a mut QlieEntryinner: Thasher: Encryption31HasherTrait Implementations
Sourceimpl<'a, T: Write> Drop for EntryWriter<'a, T>
impl<'a, T: Write> Drop for EntryWriter<'a, T>
Sourceimpl<'a, T: Write> Write for EntryWriter<'a, T>
impl<'a, T: Write> Write for EntryWriter<'a, T>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
write_all_vectored)Attempts to write multiple buffers into this writer. Read more